@@ -99,9 +99,12 @@ async def _doIterBackup(path, chunksize=1024):
     while True:
         byts = await link0.recv(chunksize)
         if not byts:
-            return
+            break
         yield byts
 
+    await coro
+    await link0.fini()
+
 async def _iterBackupWork(path, linkinfo, done):
     '''
     Inner setup for backup streaming.
@@ -126,6 +129,10 @@ def _iterBackupProc(path, linkinfo, done):
     '''
     Multiprocessing target for streaming a backup.
     '''
+    # This logging call is okay to run since we're executing in
+    # our own process space and no logging has been configured.
+    s_common.setlogging(logger, linkinfo.get('loglevel'))
+
     asyncio.run(_iterBackupWork(path, linkinfo, done))
 
 class CellApi(s_base.Base):
@@ -404,6 +411,10 @@ class CellApi(s_base.Base):
     async def addUserRole(self, useriden, roleiden):
         return await self.cell.addUserRole(useriden, roleiden)
 
+    @adminapi(log=True)
+    async def setUserRoles(self, useriden, roleidens):
+        return await self.cell.setUserRoles(useriden, roleidens)
+
     @adminapi(log=True)
     async def delUserRole(self, useriden, roleiden):
         return await self.cell.delUserRole(useriden, roleiden)
@@ -691,7 +702,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         }
     }
 
-    BACKUP_SPAWN_TIMEOUT = 4.0
+    BACKUP_SPAWN_TIMEOUT = 30.0
     BACKUP_ACQUIRE_TIMEOUT = 0.5
 
     async def __anit__(self, dirn, conf=None, readonly=False):
@@ -1165,7 +1176,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
             task.add_done_callback(functools.partial(done, self))
 
             if wait:
-                logger.info(f'Waiting for backup to complete [{name}]')
+                logger.info(f'Waiting for backup task to complete [{name}]')
                 await task
 
             return name
@@ -1190,36 +1201,43 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         mypipe, child_pipe = ctx.Pipe()
         paths = [str(slab.path) for slab in slabs]
+        loglevel = logger.getEffectiveLevel()
 
         def spawnproc():
-            proc = ctx.Process(target=self._backupProc, args=(child_pipe, self.dirn, dirn, paths))
+            logger.debug('Starting multiprocessing target')
+            proc = ctx.Process(target=self._backupProc, args=(child_pipe, self.dirn, dirn, paths, loglevel))
             proc.start()
             hasdata = mypipe.poll(timeout=self.BACKUP_SPAWN_TIMEOUT)
             if not hasdata:
-                raise s_exc.SynErr(mesg='backup subprocess stuck')
+                raise s_exc.SynErr(mesg='backup subprocess stuck starting')
             data = mypipe.recv()
             assert data == 'ready'
             return proc
 
         proc = await s_coro.executor(spawnproc)
 
+        logger.debug('Syncing LMDB Slabs')
         while True:
             await s_lmdbslab.Slab.syncLoopOnce()
             if not any(slab.dirty for slab in slabs):
                 break
 
         try:
+
+            logger.debug('Acquiring LMDB txns')
             mypipe.send('proceed')
 
             # This is technically pending the ioloop waiting for the backup process to acquire a bunch of
             # transactions.  We're effectively locking out new write requests the brute force way.
             hasdata = mypipe.poll(timeout=self.BACKUP_ACQUIRE_TIMEOUT)
             if not hasdata:
-                raise s_exc.SynErr(mesg='backup subprocess stuck')
+                raise s_exc.SynErr(mesg='backup subprocess stuck acquiring LMDB txns')
 
             data = mypipe.recv()
             assert data == 'captured'
 
+            logger.debug('Acquired LMDB txns')
+
             def waitforproc():
                 proc.join()
                 if proc.exitcode:
@@ -1228,7 +1246,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
             retn = await s_coro.executor(waitforproc)
 
         except (asyncio.CancelledError, Exception):
-            logger.exception('Error performing backup to [{dirn}]')
+            logger.exception(f'Error performing backup to [{dirn}]')
             proc.terminate()
             raise
 
@@ -1237,10 +1255,13 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
             return retn
 
     @staticmethod
-    def _backupProc(pipe, srcdir, dstdir, lmdbpaths):
+    def _backupProc(pipe, srcdir, dstdir, lmdbpaths, loglevel):
         '''
         (In a separate process) Actually do the backup
         '''
+        # This logging call is okay to run since we're executing in
+        # our own process space and no logging has been configured.
+        s_common.setlogging(logger, loglevel)
         pipe.send('ready')
         data = pipe.recv()
         assert data == 'proceed'
@@ -1295,12 +1316,13 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         cellguid = os.path.join(path, 'cell.guid')
         if not os.path.isfile(cellguid):
             mesg = 'Specified backup path has no cell.guid file.'
-            raise s_exc.BadArg(mesg=mesg)
+            raise s_exc.BadArg(mesg=mesg, arg='path', valu=path)
 
         link = s_scope.get('link')
-        linkinfo = link.getSpawnInfo()
+        linkinfo = await link.getSpawnInfo()
+        linkinfo['loglevel'] = logger.getEffectiveLevel()
 
-        await self.boss.promote('backup:stream', user=user)
+        await self.boss.promote('backup:stream', user=user, info={'name': name})
 
         ctx = multiprocessing.get_context('spawn')
         done = ctx.Queue()
@@ -1336,6 +1358,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
             raise
 
         finally:
+            logger.debug(f'iterBackupArchive completed for {name}')
             raise s_exc.DmonSpawn(mesg=mesg)
 
     async def iterNewBackupArchive(self, user, name=None, remove=False):
@@ -1353,9 +1376,11 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         try:
             await self.runBackup(name)
-            linkinfo = s_scope.get('link').getSpawnInfo()
+            link = s_scope.get('link')
+            linkinfo = await link.getSpawnInfo()
+            linkinfo['loglevel'] = logger.getEffectiveLevel()
 
-            await self.boss.promote('backup:stream', user=user)
+            await self.boss.promote('backup:stream', user=user, info={'name': name})
 
             ctx = multiprocessing.get_context('spawn')
             done = ctx.Queue()
@@ -1388,7 +1413,10 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         finally:
             if remove:
+                logger.debug(f'Removing {path}')
                 await s_coro.executor(shutil.rmtree, path, ignore_errors=True)
+                logger.debug(f'Removed {path}')
+            logger.debug(f'iterNewBackupArchive completed for {name}')
             raise s_exc.DmonSpawn(mesg=mesg)
 
     async def isUserAllowed(self, iden, perm, gateiden=None):
@@ -1455,6 +1483,11 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         await user.grant(roleiden)
         await self.fire('user:mod', act='grant', user=useriden, role=roleiden)
 
+    async def setUserRoles(self, useriden, roleidens):
+        user = await self.auth.reqUser(useriden)
+        await user.setRoles(roleidens)
+        await self.fire('user:mod', act='setroles', user=useriden, roles=roleidens)
+
     async def delUserRole(self, useriden, roleiden):
         user = await self.auth.reqUser(useriden)
         await user.revoke(roleiden)
