@@ -265,13 +265,12 @@ class Snap(s_base.Base):
             mesg = f'No tag property named {name}'
             raise s_exc.NoSuchTagProp(name=name, mesg=mesg)
 
-        for layr in self.layers:
-            genr = layr.liftByTagProp(form, tag, name)
-            async for node in self._joinStorGenr(layr, genr):
+        async for (buid, sodes) in self.core._liftByTagProp(form, tag, name, self.layers):
+            node = await self._joinSodes(buid, sodes)
+            if node is not None:
                 yield node
 
     async def nodesByTagPropValu(self, form, tag, name, cmpr, valu):
-
         prop = self.core.model.getTagProp(name)
         if prop is None:
             mesg = f'No tag property named {name}'
@@ -282,15 +281,35 @@ class Snap(s_base.Base):
         if not cmprvals:
             return
 
-        for layr in self.layers:
-            genr = layr.liftByTagPropValu(form, tag, name, cmprvals)
-            async for node in self._joinStorGenr(layr, genr):
-                if node.bylayer['tagprops'].get((tag, prop.name)) != layr:
-                    continue
+        async for (buid, sodes) in self.core._liftByTagPropValu(form, tag, name, cmprvals, self.layers):
+            node = await self._joinSodes(buid, sodes)
+            if node is not None:
                 yield node
 
     async def _joinStorNode(self, buid, cache):
 
+        node = self.livenodes.get(buid)
+        if node is not None:
+            await asyncio.sleep(0)
+            return node
+
+        layrs = (layr for layr in self.layers if layr.iden not in cache)
+        if layrs:
+            indx = 0
+            newsodes = await self.core._getStorNodes(buid, layrs)
+
+        sodes = []
+        for layr in self.layers:
+            sode = cache.get(layr.iden)
+            if sode is None:
+                sode = newsodes[indx]
+                indx += 1
+            sodes.append((layr.iden, sode))
+
+        return await self._joinSodes(buid, sodes)
+
+    async def _joinSodes(self, buid, sodes):
+
         node = self.livenodes.get(buid)
         if node is not None:
             await asyncio.sleep(0)
@@ -309,14 +328,7 @@ class Snap(s_base.Base):
             'tagprops': {},
         }
 
-        layrs = [layr for layr in self.layers if layr.iden not in cache]
-        if layrs:
-            sodes = list(await self.core._getStorNodes(buid, layrs))
-
-        for layr in self.layers:
-            sode = cache.get(layr.iden)
-            if sode is None:
-                sode = sodes.pop(0)
+        for (layr, sode) in sodes:
 
             form = sode.get('form')
             valt = sode.get('valu')
@@ -346,6 +358,7 @@ class Snap(s_base.Base):
                 nodedata.update(stordata)
 
         if ndef is None:
+            await asyncio.sleep(0)
             return None
 
         pode = (buid, {
@@ -363,18 +376,10 @@ class Snap(s_base.Base):
         await asyncio.sleep(0)
         return node
 
-    async def _joinStorGenr(self, layr, genr):
-        cache = {}
-        async for buid, sode in genr:
-            cache[layr.iden] = sode
-            node = await self._joinStorNode(buid, cache)
-            if node is not None:
-                yield node
-
     async def nodesByDataName(self, name):
-        for layr in self.layers:
-            genr = layr.liftByDataName(name)
-            async for node in self._joinStorGenr(layr, genr):
+        async for (buid, sodes) in self.core._liftByDataName(name, self.layers):
+            node = await self._joinSodes(buid, sodes)
+            if node is not None:
                 yield node
 
     async def nodesByProp(self, full):
@@ -385,34 +390,21 @@ class Snap(s_base.Base):
             raise s_exc.NoSuchProp(mesg=mesg)
 
         if prop.isrunt:
-
             async for node in self.getRuntNodes(prop.full):
                 yield node
-
             return
 
         if prop.isform:
-
-            for layr in self.layers:
-                genr = layr.liftByProp(prop.name, None)
-
-                async for node in self._joinStorGenr(layr, genr):
-
-                    # TODO merge sort rather than use bylayer
-                    if node.bylayer.get('ndef') != layr:
-                        continue
-
+            async for (buid, sodes) in self.core._liftByProp(prop.name, None, self.layers):
+                node = await self._joinSodes(buid, sodes)
+                if node is not None:
                     yield node
             return
 
         if prop.isuniv:
-
-            for layr in self.layers:
-                genr = layr.liftByProp(None, prop.name)
-                async for node in self._joinStorGenr(layr, genr):
-                    # TODO should these type of filters yield?
-                    if node.bylayer['props'].get(prop.name) != layr:
-                        continue
+            async for (buid, sodes) in self.core._liftByProp(None, prop.name, self.layers):
+                node = await self._joinSodes(buid, sodes)
+                if node is not None:
                     yield node
             return
 
@@ -421,16 +413,12 @@ class Snap(s_base.Base):
             formname = prop.form.name
 
         # Prop is secondary prop
-
-        for layr in self.layers:
-            genr = layr.liftByProp(formname, prop.name)
-            async for node in self._joinStorGenr(layr, genr):
-                if node.bylayer['props'].get(prop.name) != layr:
-                    continue
+        async for (buid, sodes) in self.core._liftByProp(formname, prop.name, self.layers):
+            node = await self._joinSodes(buid, sodes)
+            if node is not None:
                 yield node
 
     async def nodesByPropValu(self, full, cmpr, valu):
-
         if cmpr == 'type=':
             async for node in self.nodesByPropValu(full, '=', valu):
                 yield node
@@ -456,53 +444,35 @@ class Snap(s_base.Base):
             return
 
         if prop.isform:
-
-            for layr in self.layers:
-                genr = layr.liftByFormValu(prop.name, cmprvals)
-
-                async for node in self._joinStorGenr(layr, genr):
-
-                    # TODO merge sort rather than use bylayer
-                    if node.bylayer.get('ndef') != layr:
-                        continue
-
+            async for (buid, sodes) in self.core._liftByFormValu(prop.name, cmprvals, self.layers):
+                node = await self._joinSodes(buid, sodes)
+                if node is not None:
                     yield node
-
             return
 
         if prop.isuniv:
-
-            for layr in self.layers:
-                genr = layr.liftByPropValu(None, prop.name, cmprvals)
-                async for node in self._joinStorGenr(layr, genr):
-                    if node.bylayer['props'].get(prop.name) != layr:
-                        continue
+            async for (buid, sodes) in self.core._liftByPropValu(None, prop.name, cmprvals, self.layers):
+                node = await self._joinSodes(buid, sodes)
+                if node is not None:
                     yield node
-
             return
 
-        for layr in self.layers:
-            genr = layr.liftByPropValu(prop.form.name, prop.name, cmprvals)
-            async for node in self._joinStorGenr(layr, genr):
-                if node.bylayer['props'].get(prop.name) != layr:
-                    continue
+        async for (buid, sodes) in self.core._liftByPropValu(prop.form.name, prop.name, cmprvals, self.layers):
+            node = await self._joinSodes(buid, sodes)
+            if node is not None:
                 yield node
 
     async def nodesByTag(self, tag, form=None):
-        for layr in self.layers:
-            genr = layr.liftByTag(tag, form=form)
-            async for node in self._joinStorGenr(layr, genr):
-                if node.bylayer['tags'].get(tag) != layr:
-                    continue
+        async for (buid, sodes) in self.core._liftByTag(tag, form, self.layers):
+            node = await self._joinSodes(buid, sodes)
+            if node is not None:
                 yield node
 
     async def nodesByTagValu(self, tag, cmpr, valu, form=None):
         norm, info = self.core.model.type('ival').norm(valu)
-        for layr in self.layers:
-            genr = layr.liftByTagValu(tag, cmpr, norm, form=form)
-            async for node in self._joinStorGenr(layr, genr):
-                if node.bylayer['tags'].get(tag) != layr:
-                    continue
+        async for (buid, sodes) in self.core._liftByTagValu(tag, cmpr, norm, form, self.layers):
+            node = await self._joinSodes(buid, sodes)
+            if node is not None:
                 yield node
 
     async def nodesByPropTypeValu(self, name, valu):
@@ -529,25 +499,19 @@ class Snap(s_base.Base):
         cmprvals = prop.type.arraytype.getStorCmprs(cmpr, valu)
 
         if prop.isform:
-
-            for layr in self.layers:
-                genr = layr.liftByPropArray(prop.name, None, cmprvals)
-                async for node in self._joinStorGenr(layr, genr):
-                    if node.bylayer['ndef'] != layr:
-                        continue
+            async for (buid, sodes) in self.core._liftByPropArray(prop.name, None, cmprvals, self.layers):
+                node = await self._joinSodes(buid, sodes)
+                if node is not None:
                     yield node
-
             return
 
         formname = None
         if prop.form is not None:
             formname = prop.form.name
 
-        for layr in self.layers:
-            genr = layr.liftByPropArray(formname, prop.name, cmprvals)
-            async for node in self._joinStorGenr(layr, genr):
-                if node.bylayer['props'].get(prop.name) != layr:
-                    continue
+        async for (buid, sodes) in self.core._liftByPropArray(formname, prop.name, cmprvals, self.layers):
+            node = await self._joinSodes(buid, sodes)
+            if node is not None:
                 yield node
 
     async def getNodeAdds(self, form, valu, props, addnode=True):
@@ -574,6 +538,9 @@ class Snap(s_base.Base):
 
                 if prop.locked:
                     mesg = f'Prop {prop.full} is locked due to deprecation.'
+                    if not self.strict:
+                        await self.warn(mesg)
+                        continue
                     raise s_exc.IsDeprLocked(mesg=mesg)
 
                 assert prop.type.stortype is not None
@@ -586,6 +553,13 @@ class Snap(s_base.Base):
                     if ndefform is None:
                         raise s_exc.NoSuchForm(name=ndefname)
 
+                    if ndefform.locked:
+                        mesg = f'Form {ndefform.full} is locked due to deprecation.'
+                        if not self.strict:
+                            await self.warn(mesg)
+                            continue
+                        raise s_exc.IsDeprLocked(mesg=mesg)
+
                     ndefnorm, ndefinfo = ndefform.type.norm(ndefvalu)
                     do_subedit = True
                     if self.buidprefetch:
@@ -598,6 +572,13 @@ class Snap(s_base.Base):
                 elif isinstance(prop.type, s_types.Array):
                     arrayform = self.core.model.form(prop.type.arraytype.name)
                     if arrayform is not None:
+                        if arrayform.locked:
+                            mesg = f'Form {arrayform.full} is locked due to deprecation.'
+                            if not self.strict:
+                                await self.warn(mesg)
+                                continue
+                            raise s_exc.IsDeprLocked(mesg=mesg)
+
                         for arrayvalu in propnorm:
                             arraynorm, arrayinfo = arrayform.type.norm(arrayvalu)
 
@@ -709,7 +690,7 @@ class Snap(s_base.Base):
                 etyp, parms, _ = edit
 
                 if etyp == s_layer.EDIT_NODE_ADD:
-                    node.bylayer['ndef'] = wlyr
+                    node.bylayer['ndef'] = wlyr.iden
                     callbacks.append((node.form.wasAdded, (node,), {}))
                     callbacks.append((self.view.runNodeAdd, (node,), {}))
                     continue
@@ -729,7 +710,7 @@ class Snap(s_base.Base):
                         continue
 
                     node.props[name] = valu
-                    node.bylayer['props'][name] = wlyr
+                    node.bylayer['props'][name] = wlyr.iden
 
                     callbacks.append((prop.wasSet, (node, oldv), {}))
                     callbacks.append((self.view.runPropSet, (node, prop, oldv), {}))
@@ -756,7 +737,7 @@ class Snap(s_base.Base):
                     (tag, valu, oldv) = parms
 
                     node.tags[tag] = valu
-                    node.bylayer['tags'][tag] = wlyr
+                    node.bylayer['tags'][tag] = wlyr.iden
 
                     callbacks.append((self.view.runTagAdd, (node, tag, valu), {}))
                     callbacks.append((self.wlyr.fire, ('tag:add', ), {'tag': tag, 'node': node.iden()}))
@@ -776,7 +757,7 @@ class Snap(s_base.Base):
                 if etyp == s_layer.EDIT_TAGPROP_SET:
                     (tag, prop, valu, oldv, stype) = parms
                     node.tagprops[(tag, prop)] = valu
-                    node.bylayer['tags'][(tag, prop)] = wlyr
+                    node.bylayer['tags'][(tag, prop)] = wlyr.iden
                     continue
 
                 if etyp == s_layer.EDIT_TAGPROP_DEL:
@@ -1046,7 +1027,7 @@ class Snap(s_base.Base):
                     props.pop('.created', None)
 
                 oldstrict = self.strict
-                self.strict = True
+                self.strict = False
                 try:
 
                     (node, editset) = await self._getAddNodeEdits(formname, formvalu, props=props)
@@ -1096,6 +1077,10 @@ class Snap(s_base.Base):
                                     await self.warn(f'Failed to make n2 edge node for {n2iden}: invalid form')
                                     continue
 
+                                if n2form.isrunt:
+                                    await self.warn(f'Edges cannot be used with runt nodes: {n2formname}')
+                                    continue
+
                                 try:
                                     n2norm, _ = n2form.type.norm(n2valu)
                                     n2buid = s_common.buid((n2form.name, n2norm))
