@@ -12,18 +12,20 @@ import synapse.telepath as s_telepath
 
 import synapse.lib.base as s_base
 import synapse.lib.cell as s_cell
+import synapse.lib.coro as s_coro
+import synapse.lib.link as s_link
 
 import synapse.tests.utils as s_t_utils
 
 # Defective versions of spawned backup processes
-def _sleeperProc(pipe, srcdir, dstdir, lmdbpaths):
+def _sleeperProc(pipe, srcdir, dstdir, lmdbpaths, loglevel):
     time.sleep(3.0)
 
-def _sleeper2Proc(pipe, srcdir, dstdir, lmdbpaths):
+def _sleeper2Proc(pipe, srcdir, dstdir, lmdbpaths, loglevel):
     pipe.send('ready')
     time.sleep(2.0)
 
-def _exiterProc(pipe, srcdir, dstdir, lmdbpaths):
+def _exiterProc(pipe, srcdir, dstdir, lmdbpaths, loglevel):
     pipe.send('ready')
     pipe.send('captured')
     sys.exit(1)
@@ -31,6 +33,15 @@ def _exiterProc(pipe, srcdir, dstdir, lmdbpaths):
 def _backupSleep(path, linkinfo, done):
     time.sleep(3.0)
 
+async def _iterBackupEOF(path, linkinfo, done):
+    link = await s_link.fromspawn(linkinfo)
+    link.writer.write_eof()
+    await link.fini()
+    await s_coro.executor(done.put, True)
+
+def _backupEOF(path, linkinfo, done):
+    asyncio.run(_iterBackupEOF(path, linkinfo, done))
+
 class EchoAuthApi(s_cell.CellApi):
 
     def isadmin(self):
@@ -168,6 +179,26 @@ class CellTest(s_t_utils.SynTest):
                     with self.raises(s_exc.NoSuchUser):
                         await proxy.setUserPasswd('newp', 'new[')
 
+                # setRoles() allows arbitrary role ordering
+                extra_role = await echo.auth.addRole('extrarole')
+                await visi.setRoles((extra_role.iden, testrole.iden, echo.auth.allrole.iden))
+                visi_url = f'tcp://visi:foobar@127.0.0.1:{port}/echo00'
+                async with await s_telepath.openurl(visi_url) as proxy:  # type: EchoAuthApi
+                    uatm = await proxy.getUserInfo('visi')
+                    self.eq(uatm.get('roles'), ('extrarole', 'testrole', 'all',))
+
+                    # setRoles are wholesale replacements
+                    await visi.setRoles((echo.auth.allrole.iden, testrole.iden))
+                    uatm = await proxy.getUserInfo('visi')
+                    self.eq(uatm.get('roles'), ('all', 'testrole'))
+
+                # coverage test - nops short circuit
+                await visi.setRoles((echo.auth.allrole.iden, testrole.iden))
+
+                # grants must have the allrole in place
+                with self.raises(s_exc.BadArg):
+                    await visi.setRoles((extra_role.iden, testrole.iden))
+
                 # New password works
                 visi_url = f'tcp://visi:foobar@127.0.0.1:{port}/echo00'
                 async with await s_telepath.openurl(visi_url) as proxy:  # type: EchoAuthApi
@@ -823,12 +854,20 @@ class CellTest(s_t_utils.SynTest):
             bkuppath2 = os.path.join(dirn, 'bkup2.tar.gz')
             bkuppath3 = os.path.join(dirn, 'bkup3.tar.gz')
             bkuppath4 = os.path.join(dirn, 'bkup4.tar.gz')
+            bkuppath5 = os.path.join(dirn, 'bkup5.tar.gz')
 
             conf = {'backup:dir': backdirn}
             s_common.yamlsave(conf, coredirn, 'cell.yaml')
 
             async with self.getTestCore(dirn=coredirn) as core:
 
+                core.certdir.genCaCert('localca')
+                core.certdir.genHostCert('localhost', signas='localca')
+                core.certdir.genUserCert('root@localhost', signas='localca')
+
+                root = await core.auth.addUser('root@localhost')
+                await root.setAdmin(True)
+
                 nodes = await core.nodes('[test:str=streamed]')
                 self.len(1, nodes)
 
@@ -938,3 +977,27 @@ class CellTest(s_t_utils.SynTest):
             async with self.getTestCore(dirn=bkupdirn4) as core:
                 nodes = await core.nodes('test:str=noname')
                 self.len(1, nodes)
+
+            # Test backup over SSL
+            async with self.getTestCore(dirn=coredirn) as core:
+
+                nodes = await core.nodes('[test:str=ssl]')
+                addr, port = await core.dmon.listen('ssl://0.0.0.0:0?hostname=localhost&ca=localca')
+
+                async with await s_telepath.openurl(f'ssl://root@127.0.0.1:{port}?hostname=localhost') as proxy:
+                    with open(bkuppath5, 'wb') as bkup5:
+                        async for msg in proxy.iterNewBackupArchive(remove=True):
+                            bkup5.write(msg)
+
+                    with self.raises(s_exc.LinkShutDown):
+                        with mock.patch('synapse.lib.cell._iterBackupProc', _backupEOF):
+                            await s_t_utils.alist(proxy.iterNewBackupArchive('eof', remove=True))
+
+            with tarfile.open(bkuppath5, 'r:gz') as tar:
+                bkupname = os.path.commonprefix(tar.getnames())
+                tar.extractall(path=dirn)
+
+            bkupdirn5 = os.path.join(dirn, bkupname)
+            async with self.getTestCore(dirn=bkupdirn5) as core:
+                nodes = await core.nodes('test:str=ssl')
+                self.len(1, nodes)
