@@ -176,6 +176,7 @@ class StormTest(s_t_utils.SynTest):
             await core.nodes('$lib.import(foo.bar).dyncall()', opts=opts)
             await core.nodes('$lib.import(foo.bar).dyniter()', opts=opts)
 
+            self.eq(s_version.commit, await core.callStorm('return($lib.version.commit())'))
             self.eq(s_version.version, await core.callStorm('return($lib.version.synapse())'))
             self.true(await core.callStorm('return($lib.version.matches($lib.version.synapse(), ">=2.9.0"))'))
             self.false(await core.callStorm('return($lib.version.matches($lib.version.synapse(), ">0.0.1,<2.0"))'))
@@ -499,6 +500,21 @@ class StormTest(s_t_utils.SynTest):
             await core.nodes('ou:org:alias=visiacme [ :name?={[it:dev:str=hehe it:dev:str=haha]} ]')
             await core.nodes('ou:org:alias=visiacme [ :industries?={[inet:ipv4=1.2.3.0/24]} ]')
 
+    async def test_storm_dmon_user_locked(self):
+        async with self.getTestCore() as core:
+            visi = await core.auth.addUser('visi')
+            await visi.addRule((True, ('dmon', 'add')))
+            async with core.getLocalProxy(user='visi') as asvisi:
+                q = '''return($lib.dmon.add(${{ $lib.queue.gen(hehedmon).put(lolz) $lib.time.sleep(10) }},
+                                            name=hehedmon))'''
+                ddef0 = await asvisi.callStorm(q)
+
+            with self.getAsyncLoggerStream('synapse.lib.storm', 'user is locked') as stream:
+                await visi.setLocked(True)
+                q = 'return($lib.dmon.bump($iden))'
+                self.true(await core.callStorm(q, opts={'vars': {'iden': ddef0['iden']}}))
+                self.true(await stream.wait(2))
+
     async def test_storm_pipe(self):
 
         async with self.getTestCore() as core:
@@ -681,6 +697,9 @@ class StormTest(s_t_utils.SynTest):
                 await tagnode.set('doc', 'haha doc')
                 await tagnode.set('title', 'haha title')
 
+            with self.raises(s_exc.BadOperArg):
+                await core.nodes('movetag hehe hehe')
+
             await core.nodes('movetag hehe woot')
 
             self.len(0, await core.nodes('#hehe'))
@@ -1042,6 +1061,10 @@ class StormTest(s_t_utils.SynTest):
             msgs = await core.stormlist('[ media:news=* :title="https://t.c…" ] | scrape :title')
             self.stormIsInWarn('BadTypeValue', msgs)
 
+            await core.nodes('trigger.add node:add --query {[ +#foo.com ]} --form inet:ipv4')
+            msgs = await core.stormlist('syn:trigger | scrape :storm --refs')
+            self.stormIsInWarn('Edges cannot be used with runt nodes: syn:trigger', msgs)
+
     async def test_storm_tee(self):
 
         async with self.getTestCore() as core:
