@@ -695,6 +695,11 @@ class InetModelTest(s_t_utils.SynTest):
             with self.raises(s_exc.BadTypeValu):
                 t.norm(0xFFFFFFFF + 1)
 
+            with self.raises(s_exc.BadTypeValu):
+                t.norm('foo-bar.com')
+            with self.raises(s_exc.BadTypeValu):
+                t.norm('bar.com')
+
             # Form Tests ======================================================
             place = s_common.guid()
             input_props = {
@@ -740,6 +745,27 @@ class InetModelTest(s_t_utils.SynTest):
             self.len(3, await core.nodes('.created +inet:ipv4>=2'))
             self.len(0, await core.nodes('.created +inet:ipv4>=255.0.0.1'))
 
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[inet:ipv4=foo]')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[inet:ipv4=foo-bar.com]')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[inet:ipv4=foo-bar-duck.com]')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[test:str="foo"] [inet:ipv4=$node.value()]')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[test:str="foo-bar.com"] [inet:ipv4=$node.value()]')
+
+            self.len(0, await core.nodes('[inet:ipv4?=foo]'))
+            self.len(0, await core.nodes('[inet:ipv4?=foo-bar.com]'))
+
+            self.len(0, await core.nodes('[test:str="foo"] [inet:ipv4?=$node.value()] -test:str'))
+            self.len(0, await core.nodes('[test:str="foo-bar.com"] [inet:ipv4?=$node.value()] -test:str'))
+
     async def test_ipv6(self):
         formname = 'inet:ipv6'
         async with self.getTestCore() as core:
@@ -816,7 +842,29 @@ class InetModelTest(s_t_utils.SynTest):
                 node = await snap.addNode(formname, valu_str)
                 self.checkNode(node, (expected_ndef, expected_props))
 
-            await self.agenlen(1, core.eval('inet:ipv6*range=(0::1, 0::1)'))
+            self.len(1, await core.nodes('inet:ipv6=0::1'))
+            self.len(1, await core.nodes('inet:ipv6*range=(0::1, 0::1)'))
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[inet:ipv6=foo]')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[inet:ipv6=foo-bar.com]')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[inet:ipv6=foo-bar-duck.com]')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[test:str="foo"] [inet:ipv6=$node.value()]')
+
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[test:str="foo-bar.com"] [inet:ipv6=$node.value()]')
+
+            self.len(0, await core.nodes('[inet:ipv6?=foo]'))
+            self.len(0, await core.nodes('[inet:ipv6?=foo-bar.com]'))
+
+            self.len(0, await core.nodes('[test:str="foo"] [inet:ipv6?=$node.value()] -test:str'))
+            self.len(0, await core.nodes('[test:str="foo-bar.com"] [inet:ipv6?=$node.value()] -test:str'))
 
     async def test_ipv6_lift_range(self):
 
@@ -1339,6 +1387,7 @@ class InetModelTest(s_t_utils.SynTest):
                 'realname:en': 'brutus',
                 'signup': 3,
                 'signup:client': '0.0.0.4',
+                'signup:client:ipv6': '::1',
                 'tagline': 'Taglines are not tags',
                 'url': 'https://blogs.vertex.link/',
                 'webpage': 'https://blogs.vertex.link/brutus',
@@ -1358,6 +1407,7 @@ class InetModelTest(s_t_utils.SynTest):
                 'realname': 'брут',
                 'signup:client': 'tcp://0.0.0.4',
                 'signup:client:ipv4': 4,
+                'signup:client:ipv6': '::1',
                 'recovery:email': 'recovery@vertex.link',
             })
 
