@@ -101,6 +101,7 @@ class LibTst(s_stormtypes.Lib):
                   'returns': {'type': 'str', 'desc': 'The beeped string.', }}},
     )
     _storm_lib_path = ('test',)
+
     def addLibFuncs(self):
         self.locls.update({
             'beep': self.beep,
@@ -192,8 +193,10 @@ testmodel = {
         ('test:auto', ('str', {}), {}),
         ('test:edge', ('edge', {}), {}),
         ('test:guid', ('guid', {}), {}),
+        ('test:data', ('data', {}), {}),
 
         ('test:arrayprop', ('guid', {}), {}),
+        ('test:arrayform', ('array', {'type': 'int'}), {}),
 
         ('test:comp', ('comp', {'fields': (
             ('hehe', 'test:int'),
@@ -220,6 +223,11 @@ testmodel = {
         ('test:ndef', ('ndef', {}), {}),
         ('test:runt', ('str', {'lower': True, 'strip': True}), {'doc': 'A Test runt node'}),
 
+        ('test:deprprop', ('test:str', {}), {'deprecated': True}),
+        ('test:deprarray', ('array', {'type': 'test:deprprop'}), {}),
+        ('test:deprform', ('test:str', {}), {}),
+        ('test:deprndef', ('ndef', {}), {}),
+
     ),
 
     'univs': (
@@ -231,6 +239,10 @@ testmodel = {
 
         ('test:arrayprop', {}, (
             ('ints', ('array', {'type': 'test:int'}), {}),
+            ('strs', ('array', {'type': 'test:str', 'split': ','}), {}),
+            ('strsnosplit', ('array', {'type': 'test:str'}), {}),
+        )),
+        ('test:arrayform', {}, (
         )),
         ('test:type10', {}, (
 
@@ -290,6 +302,10 @@ testmodel = {
             ('posneg:isbig', ('bool', {}), {}),
         )),
 
+        ('test:data', {}, (
+            ('data', ('test:data', {}), {}),
+        )),
+
         ('test:str', {}, (
             ('bar', ('ndef', {}), {}),
             ('baz', ('nodeprop', {}), {}),
@@ -338,6 +354,13 @@ testmodel = {
             ('lulz', ('str', {}), {}),
             ('newp', ('str', {}), {'doc': 'A stray property we never use in nodes.'}),
         )),
+
+        ('test:deprprop', {}, ()),
+        ('test:deprform', {}, (
+            ('ndefprop', ('test:deprndef', {}), {}),
+            ('deprprop', ('test:deprarray', {}), {}),
+            ('okayprop', ('str', {}), {}),
+        )),
     ),
 }
 
